@@ -14,41 +14,57 @@
  * 
  */
 
+#define DEFAULT_PORT_ZERTZ 6211
+#define DEFAULT_PORT_DVONN 6221
+#define DEFAULT_PORT_BLOKS 6241
+#define DEFAULT_PORT_RELAX 6231
+
 #if (defined(VERSION_ZERTZ) && defined(VERSION_DVONN))
 #  error "something went wrong in include sequence: VERSION_ZERTZ and VERSION_DVONN defined"
 #endif
+#if (defined(VERSION_ZERTZ) && defined(VERSION_BLOKS))
+#  error "something went wrong in include sequence: VERSION_ZERTZ and VERSION_BLOKS defined"
+#endif
 #if (defined(VERSION_ZERTZ) && defined(VERSION_RELAX))
 #  error "something went wrong in include sequence: VERSION_ZERTZ and VERSION_RELAX defined"
 #endif
 #if (defined(VERSION_RELAX) && defined(VERSION_DVONN))
 #  error "something went wrong in include sequence: VERSION_RELAX and VERSION_DVONN defined"
 #endif
-
-#if (defined(VERSION_ZERTZ) && !defined(__ZERTZ_DIALOG__)) || \
-  (defined(VERSION_DVONN) && !defined(__DVONN_DIALOG__)) || \
-  (defined(VERSION_RELAX) && !defined(__RELAX_DIALOG__))
-
-#if defined(VERSION_ZERTZ)
-#  define __ZERTZ_DIALOG__
-//#  warning "using zertz..."
-#elif defined(VERSION_DVONN)
-#  define __DVONN_DIALOG__
-//#  warning "using dvonn..."
-#elif defined(VERSION_RELAX)
-#  define __RELAX_DIALOG__
-//#  warning "using relax..."
-#else
-#  error "Please define either VERSION_ZERTZ or VERSION_DVONN or VERSION_RELAX"
+#if (defined(VERSION_RELAX) && defined(VERSION_BLOKS))
+#  error "something went wrong in include sequence: VERSION_RELAX and VERSION_BLOKS defined"
+#endif
+#if (defined(VERSION_DVONN) && defined(VERSION_BLOKS))
+#  error "something went wrong in include sequence: VERSION_DVONN and VERSION_BLOKS defined"
 #endif
 
-#define DEFAULT_PORT_ZERTZ 6211
-#define DEFAULT_PORT_DVONN 6221
-#define DEFAULT_PORT_RELAX 6231
+#if (defined(VERSION_ZERTZ) && !defined(__ZERTZ_DIALOGS__)) || \
+  (defined(VERSION_DVONN) && !defined(__DVONN_DIALOGS__)) || \
+  (defined(VERSION_BLOKS) && !defined(__BLOKS_DIALOGS__)) || \
+  (defined(VERSION_RELAX) && !defined(__RELAX_DIALOGS__))
+
+#if defined(VERSION_ZERTZ)
+#  define __ZERTZ_DIALOGS__
+//#  warning "using zertz..."
+#elif defined(VERSION_DVONN)
+#  define __DVONN_DIALOGS__
+//#  warning "using dvonn..."
+#elif defined(VERSION_BLOKS)
+#  define __BLOKS_DIALOGS__
+//#  warning "using bloks..."
+#elif defined(VERSION_RELAX)
+#  define __RELAX_DIALOGS__
+//#  warning "using relax..."
+#else
+#  error "Please define either VERSION_ZERTZ or VERSION_DVONN or VERSION_BLOKS or VERSION_RELAX"
+#endif
 
 #if defined(VERSION_ZERTZ)
 namespace zertz
 #elif defined(VERSION_DVONN)
 namespace dvonn
+#elif defined(VERSION_BLOKS)
+namespace bloks
 #elif defined(VERSION_RELAX)
 namespace relax
 #endif
@@ -73,6 +89,13 @@ namespace relax
 #  include "dvonn/pbm.hpp"
 #  include "dvonn/littlegolem.hpp"
 #  define VERSION_DVONN
+#elif defined(VERSION_BLOKS)
+#  undef VERSION_BLOKS
+#  include "bloks/network.hpp"
+#  include "bloks/bloks.hpp"
+#  include "bloks/wxbloks.hpp"
+#  include "bloks/pbm.hpp"
+#  define VERSION_BLOKS
 #elif defined(VERSION_RELAX)
 #  undef VERSION_RELAX
 #  include "relax/network.hpp"
@@ -94,6 +117,8 @@ namespace relax
 namespace zertz
 #elif defined(VERSION_DVONN)
 namespace dvonn
+#elif defined(VERSION_BLOKS)
+namespace bloks
 #elif defined(VERSION_RELAX)
 namespace relax
 #endif
