@@ -14,6 +14,7 @@
  * 
  */
 
+#define MY_WX_MAKING_DLL
 #include "animations.hpp"
 
 #include "wxmain.hpp"
@@ -114,7 +115,7 @@ namespace dvonn
     
       if( done_handler )
       {
-	wxTimerEvent event( abort_id );
+	wxCommandEvent event( wxEVT_DVONN_NOTIFY, abort_id );
 	done_handler->ProcessEvent( event );
       }
     }
@@ -226,7 +227,7 @@ namespace dvonn
     
     if( done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_DVONN_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
@@ -245,11 +246,11 @@ namespace dvonn
       done_handler(0), state(finished)
   {
     // connect event functions
-    Connect( ANIMATION_DONE, wxEVT_TIMER, 
-	     (wxObjectEventFunction) (wxEventFunction) (wxTimerEventFunction) 
+    Connect( ANIMATION_DONE, wxEVT_DVONN_NOTIFY, 
+	     (wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction) 
 	     &Move_Sequence_Animation::on_done );
-    Connect( ANIMATION_ABORTED, wxEVT_TIMER, 
-	     (wxObjectEventFunction) (wxEventFunction) (wxTimerEventFunction) 
+    Connect( ANIMATION_ABORTED, wxEVT_DVONN_NOTIFY, 
+	     (wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction) 
 	     &Move_Sequence_Animation::on_aborted );
   }
 
@@ -908,8 +909,9 @@ namespace dvonn
   }
 
   // current sub-animation done
-  void Move_Sequence_Animation::on_done( wxTimerEvent &WXUNUSED(event) )
+  void Move_Sequence_Animation::on_done( wxCommandEvent& )
   {
+    //std::cout << "animation step: done" << std::endl;
     if( !undo )
       step();
     else
@@ -917,24 +919,26 @@ namespace dvonn
   }
 
   // current sub-animation aborted
-  void Move_Sequence_Animation::on_aborted( wxTimerEvent &WXUNUSED(event) )
+  void Move_Sequence_Animation::on_aborted( wxCommandEvent& )
   {
+    //std::cout << "animation: aborted" << std::endl;
     state = finished;
     
     if( done_handler )
     {
-      wxTimerEvent event( abort_id );
+      wxCommandEvent event( wxEVT_DVONN_NOTIFY, abort_id );
       done_handler->ProcessEvent( event );
     }
   }
 
   void Move_Sequence_Animation::finish()
   {
+    //std::cout << "animation: finished" << std::endl;
     state = finished;
     
     if( done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_DVONN_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
