@@ -14,6 +14,7 @@
  * 
  */
 
+#define MY_WX_MAKING_DLL
 #include "animations.hpp"
 
 #include "wxmain.hpp"
@@ -115,7 +116,7 @@ namespace relax
     
       if( done_handler )
       {
-	wxTimerEvent event( abort_id );
+	wxCommandEvent event( wxEVT_RELAX_NOTIFY, abort_id );
 	done_handler->ProcessEvent( event );
       }
     }
@@ -227,7 +228,7 @@ namespace relax
     
     if( done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_RELAX_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
@@ -246,11 +247,11 @@ namespace relax
       done_handler(0), state(finished)
   {
     // connect event functions
-    Connect( ANIMATION_DONE, wxEVT_TIMER, 
-	     (wxObjectEventFunction) (wxEventFunction) (wxTimerEventFunction) 
+    Connect( ANIMATION_DONE, wxEVT_RELAX_NOTIFY, 
+	     (wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction) 
 	     &Move_Sequence_Animation::on_done );
-    Connect( ANIMATION_ABORTED, wxEVT_TIMER, 
-	     (wxObjectEventFunction) (wxEventFunction) (wxTimerEventFunction) 
+    Connect( ANIMATION_ABORTED, wxEVT_RELAX_NOTIFY, 
+	     (wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction) 
 	     &Move_Sequence_Animation::on_aborted );
   }
 
@@ -343,7 +344,7 @@ namespace relax
 	    // ** initialize variables
 	    Set_Move *set_move = dynamic_cast<Set_Move*>(*current_move);
 	    assert( set_move );
-	    Stones::Stone_Type stone = set_move->stone_type;
+	    //Stones::Stone_Type stone = set_move->stone_type;
 
 	    // ** calculate animation positions and modify board
 	    std::pair<int,int> _from;
@@ -394,6 +395,8 @@ namespace relax
 	  case Move::no_move:
 	    ret = false;
 	    break;
+	  case Move::select_move:
+	    break;
 	}
       }
       break;
@@ -406,7 +409,7 @@ namespace relax
 	assert( Board::is_stone(stone) );
 
 	// ** modify board state
-	Field_Iterator to_field  ( set_move->pos, &game->current_player->board );
+	Mutable_Field_Iterator to_field  ( set_move->pos, &game->current_player->board );
 	*to_field = stone;
 
 	// ** begin new step
@@ -431,7 +434,7 @@ namespace relax
 	  Stones::Stone_Type &stone = current_removed_stone->second;
 
 	  // ** modify board state
-	  Field_Iterator field( field_pos, &game->current_player->board );
+	  Mutable_Field_Iterator field( field_pos, &game->current_player->board );
 	  *field = field_removed;
 
 	  // ** calculate animation positions
@@ -475,6 +478,10 @@ namespace relax
       break;
       case finished:
 	break;
+      case knock_out_jump:
+      case knock_out_collects:
+      case removing:
+	break;
     }
 
     return ret;
@@ -512,10 +519,10 @@ namespace relax
 	    // ** initialize variables
 	    Set_Move *set_move = dynamic_cast<Set_Move*>(*current_undo_move);
 	    assert( set_move );
-	    Stones::Stone_Type stone = set_move->stone_type;
+	    //Stones::Stone_Type stone = set_move->stone_type;
 
 	    // ** modify board state
-	    Field_Iterator field  ( set_move->pos, &game->current_player->board );
+	    Mutable_Field_Iterator field  ( set_move->pos, &game->current_player->board );
 	    *field = field_empty;
 
 	    // ** calculate animation positions
@@ -569,6 +576,8 @@ namespace relax
 	    ret = step_undo();
 	  }
 	  break;
+	  case Move::select_move:
+	  break;
 	}
       }
       break;
@@ -581,7 +590,7 @@ namespace relax
 	assert( Board::is_stone(stone) );
 
 	// ** modify board state
-	Field_Iterator to_field  ( set_move->pos, &game->current_player->board );
+	Mutable_Field_Iterator to_field  ( set_move->pos, &game->current_player->board );
 	*to_field = field_empty;
 
 	// readd stone to player or common stones
@@ -605,7 +614,7 @@ namespace relax
 	else
 	{
 	  // ** initialize variables
-	  Field_Pos &field_pos = current_removed_stone->first;
+	  //Field_Pos &field_pos = current_removed_stone->first;
 	  Stones::Stone_Type &stone = current_removed_stone->second;
 
 	  // ** modify board state
@@ -646,7 +655,7 @@ namespace relax
 	Stones::Stone_Type &stone = current_removed_stone->second;
 
 	// ** modify board state
-	Field_Iterator field( field_pos, &game->current_player->board );
+	Mutable_Field_Iterator field( field_pos, &game->current_player->board );
 	*field = Field_State_Type(stone); // place removed stone
 
 	// ** begin next finish animation
@@ -657,14 +666,19 @@ namespace relax
       break;
       case finished:
 	break;
+      case knock_out_jump:
+      case knock_out_collects:
+      case removing:
+	break;
     }
 
     return ret;
   }
 
   // current sub-animation done
-  void Move_Sequence_Animation::on_done( wxTimerEvent &WXUNUSED(event) )
+  void Move_Sequence_Animation::on_done( wxCommandEvent & )
   {
+    std::cout << "animation step: done " << std::endl;
     if( !undo )
       step();
     else
@@ -672,24 +686,26 @@ namespace relax
   }
 
   // current sub-animation aborted
-  void Move_Sequence_Animation::on_aborted( wxTimerEvent &WXUNUSED(event) )
+  void Move_Sequence_Animation::on_aborted( wxCommandEvent & )
   {
+    std::cout << "animation: aborted " << std::endl;
     state = finished;
     
     if( done_handler )
     {
-      wxTimerEvent event( abort_id );
+      wxCommandEvent event( wxEVT_RELAX_NOTIFY, abort_id );
       done_handler->ProcessEvent( event );
     }
   }
 
   void Move_Sequence_Animation::finish()
   {
+    std::cout << "animation: finished " << std::endl;
     state = finished;
     
     if( done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_RELAX_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
