@@ -133,14 +133,14 @@ namespace relax
   // Field_Iterator
   // ----------------------------------------------------------------------------
 
-  Field_Iterator::Field_Iterator( Board *board )
+  Field_Iterator::Field_Iterator( const Board *board )
     : board(board)
   {
     current_pos.x = 0;
     current_pos.y = 0;
   }
 
-  Field_Iterator::Field_Iterator( Field_Pos pos, Board *board )
+  Field_Iterator::Field_Iterator( Field_Pos pos, const Board *board )
     : current_pos(pos), board(board)
   {
   }
@@ -429,7 +429,7 @@ namespace relax
   }
 
   //! tells whether field is in range
-  bool Field_Iterator::is_valid_field()
+  bool Field_Iterator::is_valid_field() const
   {
     if( board == 0 ) return false;
     if( current_pos.x < 0 ) return false;
@@ -440,13 +440,20 @@ namespace relax
     return true;
   }
 
-  Field_State_Type &Field_Iterator::operator*()
+  Field_State_Type Field_Iterator::operator*() const
   {
     assert( is_valid_field() );
 
     return board->field[ current_pos.x ][ current_pos.y ];
   }
 
+  Field_State_Type &Mutable_Field_Iterator::operator*()
+  {
+    assert( is_valid_field() );
+
+    return mutable_board->field[ current_pos.x ][ current_pos.y ];
+  }
+
   // ----------------------------------------------------------------------------
   // Board
   // ----------------------------------------------------------------------------
@@ -918,21 +925,21 @@ namespace relax
 	(players.size() > ruleset->max_players) ) 
       return wrong_number_of_players;
 
-    // check win condition
+    // check win condition (not active for relax)
     if( prev_player != players.end() )
     {
       if( win_condition->did_player_win(*this,*prev_player) )
       {
 	winner_player_index = prev_player_index;
 	current_player->is_active = false;
-	return finished;
+	return finished_scores;
       }
     }
 
     if( !current_player->is_active ) // if no player is able to move
     {
       winner_player_index=-1;
-      return finished;
+      return finished_scores;
     }
 
     if( current_player->board.get_empty_fields().empty() )
@@ -1060,13 +1067,13 @@ namespace relax
     reset_game();
   }
 
-  std::multimap<int/*score*/,Player*> Game::get_scores()
+  std::multimap<int/*score*/,const Player*> Game::get_scores() const
   {
-    std::multimap<int/*score*/,Player*> ret;
-    std::vector<Player>::iterator it;
+    std::multimap<int/*score*/,const Player*> ret;
+    std::vector<Player>::const_iterator it;
     for( it = players.begin(); it != players.end(); ++it )
     {
-      Player *player = &*it;
+      const Player *player = &*it;
       int score = get_max_score(player);
       ret.insert(std::make_pair(score,player));
     }
@@ -1481,22 +1488,24 @@ namespace relax
     unsigned assigned_index;
   };
 
-  int Game::get_max_score(Player *player, std::vector<std::map<int/*num*/, 
-			  unsigned /*stones*/> > *stones_available)
+  std::pair<int, std::list<std::pair<int/*count*/,int/*num*/> > > 
+  Game::get_max_score_detail(const Player *player, std::vector<std::map<int/*num*/, 
+			     unsigned /*stones*/> > *stones_available) const
   {
-    Board &board = player?player->board:current_player->board;
+    std::list<std::pair<int/*count*/,int/*num*/> > scores;
+    const Board &board = player?player->board:current_player->board;
     std::map<unsigned/*dir*/,std::map<int/*num*/,std::list<Speculative_Score> > > 
       speculative_scores;
     std::map<unsigned/*dir*/,std::list<Speculative_Score> > 
       any_num_speculative_scores;
     int score = 0;
     Field_Iterator main_it(Field_Pos(0,0),&board);
-    if( !main_it.is_valid_field() ) return 0;
+    if( !main_it.is_valid_field() ) return std::make_pair(0,scores);
     // find top-left-corner
     while( *main_it == field_removed )
       {
 	main_it.Right();
-	if( !main_it.is_valid_field() ) return 0;
+	if( !main_it.is_valid_field() ) return std::make_pair(0,scores);
       }
     Field_Iterator corner = main_it;
     Field_Iterator it1(&board),it2(&board);
@@ -1545,6 +1554,7 @@ namespace relax
 	if( valid && cur_num_set )
 	  {
 	    int add_score=0;
+	    scores.push_back(std::make_pair(int(count),cur_num));
 	    if( stones_available )
 	      {
 		if( (*stones_available)[right_dir][cur_num] >= missing )
@@ -1609,6 +1619,7 @@ namespace relax
 	if( valid && cur_num_set )
 	  {
 	    int add_score=0;
+	    scores.push_back(std::make_pair(int(count),cur_num));
 	    if( stones_available )
 	      {
 		if( (*stones_available)[bottom_left_dir][cur_num] >= missing )
@@ -1691,6 +1702,7 @@ namespace relax
 	if( valid && cur_num_set )
 	  {
 	    int add_score=0;
+	    scores.push_back(std::make_pair(int(count),cur_num));
 	    if( stones_available )
 	      {
 		if( (*stones_available)[bottom_right_dir][cur_num] >= missing )
@@ -1841,6 +1853,14 @@ namespace relax
 // 	      }
 // 	  }
       }
+
+    return std::make_pair(score, scores);
+  }
+
+  int Game::get_max_score(const Player *player, std::vector<std::map<int/*num*/, 
+			  unsigned /*stones*/> > *stones_available) const
+  {
+    int score = get_max_score_detail(player, stones_available).first;
     //std::cout << "score=" << score << std::endl;
     return score;
   }
@@ -1924,11 +1944,11 @@ namespace relax
   {
     return move == 0;
   }
-  bool Set_Move::may_be_first_move( Game &game ) const
+  bool Set_Move::may_be_first_move( Game & /*game*/ ) const
   {
     return true;
   }
-  bool Set_Move::may_be_last_move( Game &game ) const
+  bool Set_Move::may_be_last_move( Game & /*game*/ ) const
   {
     return true;
   }
@@ -2003,11 +2023,11 @@ namespace relax
   {
     return move == 0;
   }
-  bool Select_Move::may_be_first_move( Game &game ) const
+  bool Select_Move::may_be_first_move( Game & /*game*/ ) const
   {
     return true;
   }
-  bool Select_Move::may_be_last_move( Game &game ) const
+  bool Select_Move::may_be_last_move( Game & /*game*/ ) const
   {
     return true;
   }
@@ -2051,15 +2071,15 @@ namespace relax
     return finish_move;
   }
 
-  void Finish_Move::do_move( Game &game )
+  void Finish_Move::do_move( Game & /*game*/ )
   {
   }
-  void Finish_Move::undo_move( Game &game )
+  void Finish_Move::undo_move( Game & /*game*/ )
   {
   }
 
   // true: move ok
-  bool Finish_Move::check_move( Game &game ) const 
+  bool Finish_Move::check_move( Game & /*game*/ ) const 
   {
     return true;
   }
@@ -2085,7 +2105,7 @@ namespace relax
     eos << get_type();
     return eos;
   }
-  bool Finish_Move::input( std::escape_istream &is )
+  bool Finish_Move::input( std::escape_istream & /*is*/ )
   {
     return true;
   }
