@@ -48,12 +48,14 @@
 // headers
 // ----------------------------------------------------------------------------
 
+#define MY_WX_MAKING_DLL // for WX MSW using mingw cross-compile
 #include "wxrelax.hpp"
 #include "relax.hpp"
 #include "dialogs.hpp"
 #include "ai.hpp"
 #include "util.hpp"
 #include "wxmain.hpp"
+#include "wxutil.hpp"
 
 #include <wx/zipstrm.h>
 #include <wx/image.h>
@@ -63,6 +65,7 @@
 #include <wx/fs_zip.h>
 #include <wx/html/helpctrl.h>
 #include <wx/cshelp.h>
+#include <wx/numdlg.h>
 /*
 #ifndef __OLD_GCC__
   #include <sstream>
@@ -77,6 +80,9 @@
 #error "wxHTML is required for the wxWindows HTML help system."
 #endif
 
+// define custom event type wx_EVT_RELAX_NOTIFY
+DEFINE_EVENT_TYPE(wxEVT_RELAX_NOTIFY)
+
 namespace relax
 {
   using namespace holtz;
@@ -547,6 +553,9 @@ namespace relax
 	
 	switch( state )
 	{
+	  case Sequence_Generator::hold_stone_begin:
+	  case Sequence_Generator::hold_stone_end:
+	    break;
 	  case Sequence_Generator::finished:
 	    gui_manager.set_mark(-1,-1);
 	    sequence_generator = 0;
@@ -765,7 +774,7 @@ namespace relax
       }
   }
 
-  void Stone_Panel::draw_text( wxDC &dc ) const
+  void Stone_Panel::draw_text( wxDC & ) const
   {
 //     if( stones.current_stone != Stones::invalid_stone )
 //       {
@@ -791,7 +800,7 @@ namespace relax
 //       }
   }
   
-  void Stone_Panel::on_click( int click_x, int click_y ) const
+  void Stone_Panel::on_click( int /*click_x*/, int /*click_y*/ ) const
   {
 	/*
     wxString msg;
@@ -1173,13 +1182,13 @@ namespace relax
     return used_time;
   }
 
-  void Mouse_Handler::on_animation_done( wxTimerEvent& )
+  void Mouse_Handler::on_animation_done( wxCommandEvent& )
   {
     game_manager.continue_game();
   }
 
   BEGIN_EVENT_TABLE(Mouse_Handler, wxEvtHandler)				
-    EVT_TIMER(-1, Mouse_Handler::on_animation_done)	//**/
+    EVT_COMMAND(-1, wxEVT_RELAX_NOTIFY, Mouse_Handler::on_animation_done)	//**/
   END_EVENT_TABLE()					//**/
 
   // ----------------------------------------------------------------------------
@@ -1232,8 +1241,8 @@ namespace relax
   {
     if( sequence_generator )
     {
-      Sequence_Generator::Sequence_State state;
-      state = sequence_generator->undo_click();
+      //Sequence_Generator::Sequence_State state;
+      /*state =*/ sequence_generator->undo_click();
       /*	
       switch( state )
       {
@@ -1492,26 +1501,91 @@ namespace relax
     update_board( new_game );
   }
 
+  static bool check_player_references_changed(const Game &g1, const Game &g2)
+  {
+    if( g1.players.size() != g2.players.size() ) return true;
+    std::vector<Player>::const_iterator it1,it2;
+    for(it1=g1.players.begin(), it2=g2.players.begin(); 
+	it1!=g1.players.end() && it2!=g2.players.end(); ++it1, ++it2)
+    {
+      const Player &player1 = *it1;
+      const Player &player2 = *it2;
+      if( &player1 != &player2 ) return true;
+    }
+    if( it1!=g1.players.end() ) return true;
+    if( it2!=g2.players.end() ) return true;
+    
+    return false;
+  }
+
   void WX_GUI_Manager::update_board( const Game &new_game )
   {
     std::list<unsigned> variant_id_path;
     if( target_variant )
       variant_id_path = display_game.variant_tree.get_variant_id_path(target_variant);
-    display_game = new_game;
-    game_panel.update_player_panels();
+    bool player_references_changed = check_player_references_changed(display_game,new_game);
+    display_game = new_game; // attention: make sure that setup_game_display is called whenever players change
     if( target_variant )
       target_variant = display_game.variant_tree.get_variant(variant_id_path);
-    refresh();
+
+    if( player_references_changed )
+      setup_game_display();
+    else
+      refresh();
   }
 
-  void WX_GUI_Manager::report_scores( std::multimap<int/*score*/,Player*> scores )
+  void WX_GUI_Manager::report_scores( const Game* game, 
+				      std::multimap<int/*score*/,const Player*> scores )
   {
+    bool activate_math_exercise = true;  // this is a special hack for my friend Samuel
+    int math_exercise_max_cnt = 3; // maximum number of questions asked
     wxString msg, line;
-    std::multimap<int/*score*/,Player*>::iterator it;
+    std::multimap<int/*score*/,const Player*>::iterator it;
     for( it=scores.begin(); it!=scores.end(); ++it )
       {
 	int score = it->first;
-	Player *player = it->second;
+	const Player *player = it->second;
+	// math_excercise: ask for help to compute total scores (learn multiplication) 
+	if( activate_math_exercise && player->type == Player::user ) 
+	{
+	  std::list<std::pair<int/*count*/,int/*num*/> > scores 
+	    = game->get_max_score_detail(player).second;
+	  int cnt = 0;
+	  for( std::list<std::pair<int/*count*/,int/*num*/> >::iterator it = scores.begin();
+	       it != scores.end(); ++it )
+	    {
+	      if( ++cnt > math_exercise_max_cnt ) break;
+	      int count = it->first;
+	      int num = it->second;
+	      wxString hint = wxT("");
+	      long result;
+	      do{
+		wxString base_question = _("%s: Please help me calculate %d * %d%s");
+		wxString title = _("Calculate Scores");
+		wxString question;
+		question.Printf( base_question,
+				 str_to_wxstr(player->name).c_str(), count, num, 
+				 hint.c_str() );
+		result = wxGetNumberFromUser( question, /*prompt=*/_("= "), 
+					      title,
+					      /*value=*/-1, /*min=*/0, /*max=*/1000, 
+					      /*parent=*/&game_window );
+		if( result != count*num ) 
+		  {
+		    if( result < count*num ) 
+		      {
+			hint.Printf( _(" (Hint: the actual result is higher than %d)"), 
+				       result);
+		      }
+		    else
+		      {
+			hint.Printf( _(" (Hint: the actual result is lower than %d)"), 
+				       result);
+		      }
+		  }
+	      }while(result != count*num);
+	    }
+	}
 	line.Printf( _("%3d points: %s\n"), score, str_to_wxstr(player->name).c_str() );
 	msg += line;
       }
@@ -1702,7 +1776,7 @@ namespace relax
 
     if( !ret && done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_RELAX_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
@@ -1724,7 +1798,7 @@ namespace relax
 
     if( !ret && done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_RELAX_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
@@ -1804,7 +1878,7 @@ namespace relax
     {
       buf = wxFileSelector( _("Choose a skin File"), wxT(""), 
 			    wxT(""), wxT(""), _("Skin Files (*.zip)|*.zip"),
-			    wxOPEN );
+			    wxFD_OPEN );
       if( wxFileExists(buf) )
       {
 	if( load_skin( buf ) )
@@ -1886,7 +1960,7 @@ namespace relax
     {
       buf = wxFileSelector( _("Choose a sound file as move reminder"), wxT(""),
 			    wxT(""), wxT(""), _("Sound Files (*.wav)|*.wav"),
-			    wxOPEN );
+			    wxFD_OPEN );
       if( wxFileExists(buf) )
       {
 	if( load_beep(buf) )
@@ -1934,15 +2008,15 @@ namespace relax
     show_user_information(false,false);
 
     Standard_Ruleset ruleset;	// to lookup numbers
-    wxZipInputStream *input;
+    wxInputStream *input;
     wxImage image;
 
-    input = new wxZipInputStream( filename, wxT("field_removed.png") );
+    input = get_zip_input_stream( filename, wxT("field_removed.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.field_bitmaps[field_removed] = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("field_empty.png") );
+    input = get_zip_input_stream( filename, wxT("field_empty.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.field_bitmaps[field_empty] = wxBitmap(image);
@@ -1955,41 +2029,41 @@ namespace relax
 	    int num = *it;
 	    std::string stone_file = "stone_" + long_to_string(dir) + "_" + 
 	      long_to_string(num) + ".png";
-	    input = new wxZipInputStream( filename, str_to_wxstr(stone_file) );
+	    input = get_zip_input_stream( filename, str_to_wxstr(stone_file) );
 	    if( input->Eof() ) { delete input; return false; }
 	    image.LoadFile( *input, wxBITMAP_TYPE_PNG );
 	    bitmap_handler.normal.num_bitmaps[dir][num] = wxBitmap(image);
 	    delete input;
 	  }
       }
-    input = new wxZipInputStream( filename, wxT("stone_base.png") );
+    input = get_zip_input_stream( filename, wxT("stone_base.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.stone_base = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("click_mark.png") );
+    input = get_zip_input_stream( filename, wxT("click_mark.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.click_mark = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("field_mark.png") );
+    input = get_zip_input_stream( filename, wxT("field_mark.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.field_mark = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("stone_mark.png") );
+    input = get_zip_input_stream( filename, wxT("stone_mark.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.stone_mark = wxBitmap(image);
     delete input;
 
-    input = new wxZipInputStream( filename, wxT("background.png") );
+    input = get_zip_input_stream( filename, wxT("background.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.background = wxBitmap(image);
     delete input;
 
-    input = new wxZipInputStream( filename, wxT("skin.ini") );
+    input = get_zip_input_stream( filename, wxT("skin.ini") );
     //if( input->Eof() ) { delete input; return false; } // ini file might be empty
     wxFileConfig config( *input );
     bitmap_handler.dimensions 
