@@ -13,6 +13,8 @@
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  * 
  */
+
+#define MY_WX_MAKING_DLL // for WX MSW using mingw cross-compile
 #include "network.hpp" // workaround for cygwin 
 
 #include "ai.hpp"
@@ -875,11 +877,14 @@ namespace zertz
     else
     {
       AI_Event event( get_move(game), EVT_AI_REPORT_MOVE, this ); 
+      if( TestDestroy() ) return 0;
       handler->AddPendingEvent( event );
     }
 
     Sleep(200);			// assure that report move event is received earlier
 
+    if( TestDestroy() ) return 0;
+
     AI_Event event( EVT_AI_FINISHED, this ); 
     handler->AddPendingEvent( event );
 
@@ -909,7 +914,7 @@ namespace zertz
   void AI_Thread::report_current_hint( AI_Result hint )
   {
     AI_Event event( hint, EVT_AI_REPORT_HINT, this ); 
-
+    if( TestDestroy() ) return;
     handler->AddPendingEvent( event );
   }
 
@@ -962,8 +967,8 @@ namespace zertz
 	     (wxObjectEventFunction) (wxEventFunction) (AI_Event_Function) 
 	     &AI_Input::on_finished );
 
-    Connect( -1, wxEVT_TIMER, 
-	     (wxObjectEventFunction) (wxEventFunction) (wxTimerEventFunction) 
+    Connect( -1, wxEVT_ZERTZ_NOTIFY, 
+	     (wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction) 
 	     &AI_Input::on_animation_done );
   }
 
@@ -1072,7 +1077,7 @@ namespace zertz
     }
   }
 
-  void AI_Input::on_animation_done( wxTimerEvent &event )
+  void AI_Input::on_animation_done( wxCommandEvent & )
   {
     move_done = true;
     game_manager.continue_game();
