@@ -48,12 +48,14 @@
 // headers
 // ----------------------------------------------------------------------------
 
+#define MY_WX_MAKING_DLL // for WX MSW using mingw cross-compile
 #include "wxzertz.hpp"
 #include "zertz.hpp"
 #include "dialogs.hpp"
 #include "ai.hpp"
 #include "util.hpp"
 #include "wxmain.hpp"
+#include "wxutil.hpp"
 
 #include <wx/zipstrm.h>
 #include <wx/image.h>
@@ -77,6 +79,9 @@
 #error "wxHTML is required for the wxWindows HTML help system."
 #endif
 
+// define custom event type wx_EVT_ZERTZ_NOTIFY
+DEFINE_EVENT_TYPE(wxEVT_ZERTZ_NOTIFY)
+
 namespace zertz
 {
   using namespace holtz;
@@ -1222,13 +1227,13 @@ namespace zertz
     return used_time;
   }
 
-  void Mouse_Handler::on_animation_done( wxTimerEvent& )
+  void Mouse_Handler::on_animation_done( wxCommandEvent& )
   {
     game_manager.continue_game();
   }
 
   BEGIN_EVENT_TABLE(Mouse_Handler, wxEvtHandler)				
-    EVT_TIMER(-1, Mouse_Handler::on_animation_done)	//**/
+    EVT_COMMAND(-1, wxEVT_ZERTZ_NOTIFY, Mouse_Handler::on_animation_done)	//**/
   END_EVENT_TABLE()					//**/
 
   // ----------------------------------------------------------------------------
@@ -1498,25 +1503,48 @@ namespace zertz
     update_board( new_game );
   }
 
+  static bool check_player_references_changed(const Game &g1, const Game &g2)
+  {
+    if( g1.players.size() != g2.players.size() ) return true;
+    std::vector<Player>::const_iterator it1,it2;
+    for(it1=g1.players.begin(), it2=g2.players.begin(); 
+	it1!=g1.players.end() && it2!=g2.players.end(); ++it1, ++it2)
+    {
+      const Player &player1 = *it1;
+      const Player &player2 = *it2;
+      if( &player1 != &player2 ) return true;
+    }
+    if( it1!=g1.players.end() ) return true;
+    if( it2!=g2.players.end() ) return true;
+    
+    return false;
+  }
+
   void WX_GUI_Manager::update_board( const Game &new_game )
   {
     std::list<unsigned> variant_id_path;
     if( target_variant )
       variant_id_path = display_game.variant_tree.get_variant_id_path(target_variant);
-    display_game = new_game;
+    bool player_references_changed = check_player_references_changed(display_game,new_game);
+    display_game = new_game; // attention: make sure that setup_game_display is called whenever players change
     if( target_variant )
       target_variant = display_game.variant_tree.get_variant(variant_id_path);
-    refresh();
+
+    if( player_references_changed )
+      setup_game_display();
+    else
+      refresh();
   }
 
-  void WX_GUI_Manager::report_scores( std::multimap<int/*score*/,Player*> scores )
+  void WX_GUI_Manager::report_scores( const Game*, 
+				      std::multimap<int/*score*/,const Player*> scores )
   {
     wxString msg, line;
-    std::multimap<int/*score*/,Player*>::iterator it;
+    std::multimap<int/*score*/,const Player*>::iterator it;
     for( it=scores.begin(); it!=scores.end(); ++it )
       {
 	int score = it->first;
-	Player *player = it->second;
+	const Player *player = it->second;
 	line.Printf( _("%3d points: %s\n"), score, str_to_wxstr(player->name).c_str() );
 	msg += line;
       }
@@ -1775,7 +1803,7 @@ namespace zertz
 
     if( !ret && done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_ZERTZ_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
@@ -1797,7 +1825,7 @@ namespace zertz
 
     if( !ret && done_handler )
     {
-      wxTimerEvent event( event_id );
+      wxCommandEvent event( wxEVT_ZERTZ_NOTIFY, event_id );
       done_handler->ProcessEvent( event );
     }
   }
@@ -1877,7 +1905,7 @@ namespace zertz
     {
       buf = wxFileSelector( _("Choose a skin File"), wxT(""), 
 			    wxT(""), wxT(""), _("Skin Files (*.zip)|*.zip"),
-			    wxOPEN );
+			    wxFD_OPEN );
       if( wxFileExists(buf) )
       {
 	if( load_skin( buf ) )
@@ -1959,7 +1987,7 @@ namespace zertz
     {
       buf = wxFileSelector( _("Choose a sound file as move reminder"), wxT(""),
 			    wxT(""), wxT(""), _("Sound Files (*.wav)|*.wav"),
-			    wxOPEN );
+			    wxFD_OPEN );
       if( wxFileExists(buf) )
       {
 	if( load_beep(buf) )
@@ -2006,58 +2034,58 @@ namespace zertz
   {
     show_user_information(false,false);
 
-    wxZipInputStream *input;
+    wxInputStream *input;
     wxImage image;
 
-    input = new wxZipInputStream( filename, wxT("field_removed.png") );
+    input = get_zip_input_stream( filename, wxT("field_removed.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.field_bitmaps[field_removed] = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("field_empty.png") );
+    input = get_zip_input_stream( filename, wxT("field_empty.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.field_bitmaps[field_empty] = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("stone_white.png") );
+    input = get_zip_input_stream( filename, wxT("stone_white.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.stone_bitmaps[Stones::white_stone] = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("stone_grey.png") );
+    input = get_zip_input_stream( filename, wxT("stone_grey.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.stone_bitmaps[Stones::grey_stone] = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("stone_black.png") );
+    input = get_zip_input_stream( filename, wxT("stone_black.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.stone_bitmaps[Stones::black_stone] = wxBitmap(image);
     delete input;
 
-    input = new wxZipInputStream( filename, wxT("click_mark.png") );
+    input = get_zip_input_stream( filename, wxT("click_mark.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.click_mark = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("field_mark.png") );
+    input = get_zip_input_stream( filename, wxT("field_mark.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.field_mark = wxBitmap(image);
     delete input;
-    input = new wxZipInputStream( filename, wxT("stone_mark.png") );
+    input = get_zip_input_stream( filename, wxT("stone_mark.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.stone_mark = wxBitmap(image);
     delete input;
 
-    input = new wxZipInputStream( filename, wxT("background.png") );
+    input = get_zip_input_stream( filename, wxT("background.png") );
     if( input->Eof() ) { delete input; return false; }
     image.LoadFile( *input, wxBITMAP_TYPE_PNG );
     bitmap_handler.normal.background = wxBitmap(image);
     delete input;
 
-    input = new wxZipInputStream( filename, wxT("skin.ini") );
+    input = get_zip_input_stream( filename, wxT("skin.ini") );
     //if( input->Eof() ) { delete input; return false; } // ini file might be empty
     wxFileConfig config( *input );
     bitmap_handler.dimensions 
